@@ -334,6 +334,6 @@ module_afrtran (RECODE_OUTER outer)
 }
 
 void
-delmodule_afrtran (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_afrtran (_GL_UNUSED RECODE_OUTER outer)
 {
 }
